@@ -173,11 +173,14 @@ class BinarySemSegImgPatchDataset(PatchedImgDataset):
             img_obj.array, img_obj.ground_truth, img_obj.mask = _imgutils.masked_bboxcrop(
                 img_obj.array,
                 img_obj.ground_truth,
-                dspec.setdefault('bbox_crop_offset', 51)
+                offset=dspec.setdefault('bbox_crop_offset', 51)
             )
 
-            if img_obj.array.shape[0] < dspec['patch_shape'][0] or img_obj.array.shape[1] < dspec['patch_shape'][1]:
-                _warn.warn(f"BBOX crop reversing for {dspec['name']}:{img_obj.file}, shape: {img_obj.array.shape}")
+            if img_obj.array.shape[0] / copy.array.shape[0] < 0.51 \
+                    or img_obj.array.shape[1] / copy.array.shape[1] < 0.51:
+                _warn.warn(f"BBOX crop reversing for "
+                           f"{dspec['name']}:{img_obj.file}, shape: {img_obj.array.shape}, {copy.array.shape}"
+                           )
                 img_obj = copy.copy()
 
         if dspec.get('resize'):
@@ -256,11 +259,11 @@ class FullImgDataset(BaseImageDataset):
             copy = img_obj.copy()
             img_obj.array, img_obj.mask = _imgutils.masked_bboxcrop(
                 img_obj.array,
-                dspec.setdefault('bbox_crop_offset', 31)
+                offset=dspec.setdefault('bbox_crop_offset', 31)
             )
 
-            if img_obj.array.shape[0] / copy.array.shape[0] < 0.65 \
-                    or img_obj.array.shape[1] / copy.array.shape[1] < 0.65:
+            if img_obj.array.shape[0] / copy.array.shape[0] < 0.51 \
+                    or img_obj.array.shape[1] / copy.array.shape[1] < 0.51:
                 _warn.warn(f"BBOX crop reversing for {dspec['name']}:{img_obj.file}, shape: {img_obj.array.shape}")
                 img_obj = copy.copy()
 
